'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

var _webpack = require('webpack');

var _webpack2 = _interopRequireDefault(_webpack);

var _extractTextWebpackPlugin = require('extract-text-webpack-plugin');

var _extractTextWebpackPlugin2 = _interopRequireDefault(_extractTextWebpackPlugin);

var _babelrc = require('./babelrc');

var _babelrc2 = _interopRequireDefault(_babelrc);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var CURRENTDIR = _path2.default.join(__dirname, '..');

var BABEL_LOADER = {
  loader: 'babel-loader',
  options: _babelrc2.default
};
var URL_LOADER = {
  loader: 'url-loader',
  options: {
    limit: 25000
  }
};
var RESOLVE_URL = 'resolve-url-loader';
var STYLE_LOADER = 'style-loader';
var CSS_LITERAL_LOADER = 'css-literal-loader';
var CSS_LOADER = {
  loader: 'css-loader',
  options: {
    sourceMap: true
  }
};
var POSTCSS_LOADER = {
  loader: 'postcss-loader',
  options: {
    ident: 'postcss-options',
    plugins: function plugins() {
      return [require('autoprefixer')];
    },
    sourceMap: true
  }
};

exports.default = function (options) {
  return {
    context: options.context,
    entry: options.entry,
    output: options.output,
    devtool: options.devtool,

    plugins: [new _webpack2.default.NoEmitOnErrorsPlugin(), new _webpack2.default.DefinePlugin({
      'process.env': {
        NODE_ENV: options.production ? '"production"' : '"developement"'
      }
    }), new _webpack2.default.LoaderOptionsPlugin({
      minimize: !!options.production,
      debug: !options.production
    })].concat(options.production ? [new _webpack2.default.optimize.UglifyJsPlugin({
      compress: { warnings: false },
      sourceMap: !!options.devtool
    }), new _extractTextWebpackPlugin2.default({
      filename: 'style.css'
    })] : [new _webpack2.default.NamedModulesPlugin()]).concat(options.plugins || []),

    module: {
      rules: [{
        test: /\.js$/,
        exclude: /node_modules/,
        use: [BABEL_LOADER, CSS_LITERAL_LOADER]
      }, {
        test: /\.(gif|jpg|png|webp|svg)$/,
        use: URL_LOADER
      }, {
        test: /\.css$/,
        use: options.production ? _extractTextWebpackPlugin2.default.extract({
          fallback: 'style-loader',
          use: [CSS_LOADER, RESOLVE_URL, POSTCSS_LOADER]
        }) : [STYLE_LOADER, CSS_LOADER, RESOLVE_URL, POSTCSS_LOADER]
      }]
    },

    resolveLoader: {
      modules: [_path2.default.join(CURRENTDIR, 'node_modules'), _path2.default.join(options.context, 'node_modules')]
    },

    resolve: {
      modules: [_path2.default.join(CURRENTDIR, 'node_modules'), _path2.default.join(options.context, 'node_modules')]
    },

    devServer: {
      stats: {
        colors: true,
        chunks: false
      }
    }
  };
};
//# sourceMappingURL=configure-webpack.js.map